/* Copyright (c) 2015 - 2021, Nordic Semiconductor ASA
 *
 * All rights reserved.
 *
 * Use in source and binary forms, redistribution in binary form only, with
 * or without modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions in binary form, except as embedded into a Nordic
 *    Semiconductor ASA integrated circuit in a product or a software update for
 *    such product, must reproduce the above copyright notice, this list of
 *    conditions and the following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 2. Neither the name of Nordic Semiconductor ASA nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * 3. This software, with or without modification, must only be used with a Nordic
 *    Semiconductor ASA integrated circuit.
 *
 * 4. Any software provided in binary form under this license must not be reverse
 *    engineered, decompiled, modified and/or disassembled.
 *
 * THIS SOFTWARE IS PROVIDED BY NORDIC SEMICONDUCTOR ASA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL NORDIC SEMICONDUCTOR ASA OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import React from 'react';
import { Vector3 } from 'three';

const length = 2;
const headLength = 0.2 * length;
const headWidth = 0.8 * headLength;
const origin = new Vector3(0, 0, 0).normalize();

interface Props {
    rotation: Vector3;
    colour: string;
    text: string;
    labelOffset: Vector3;
}

const Axis: React.FC<Props> = ({ rotation, colour, text, labelOffset }) => {
    const canvas = document.createElement('canvas');
    const centerX = canvas.width / 2;
    const centerY = canvas.height / 2;
    const context = canvas.getContext('2d');
    if (context) {
        context.textBaseline = 'middle';
        context.font = `bold 30px helvetica`;
        context.lineWidth = 4;
        context.fillStyle = 'black';
        context.textAlign = 'center';
        context.fillText(text, centerX, centerY);
    }

    return (
        <group>
            <group position={labelOffset}>
                <sprite scale={[3, 1.5, 3]}>
                    <spriteMaterial attach="material">
                        <canvasTexture attach="map" image={canvas} />
                    </spriteMaterial>
                </sprite>
            </group>
            <arrowHelper
                args={[rotation, origin, length, colour, headLength, headWidth]}
            />
        </group>
    );
};

export default Axis;
