/* Copyright (c) 2015 - 2021, Nordic Semiconductor ASA
 *
 * All rights reserved.
 *
 * Use in source and binary forms, redistribution in binary form only, with
 * or without modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions in binary form, except as embedded into a Nordic
 *    Semiconductor ASA integrated circuit in a product or a software update for
 *    such product, must reproduce the above copyright notice, this list of
 *    conditions and the following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 2. Neither the name of Nordic Semiconductor ASA nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * 3. This software, with or without modification, must only be used with a Nordic
 *    Semiconductor ASA integrated circuit.
 *
 * 4. Any software provided in binary form under this license must not be reverse
 *    engineered, decompiled, modified and/or disassembled.
 *
 * THIS SOFTWARE IS PROVIDED BY NORDIC SEMICONDUCTOR ASA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL NORDIC SEMICONDUCTOR ASA OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import React, { useState } from 'react';
import Modal from 'react-bootstrap/Modal';

const Help: React.FC = () => {
    const [showingHelp, setShowHelp] = useState(false);

    return (
        <>
            <button
                type="button"
                className="help-button"
                onClick={() => setShowHelp(true)}
            >
                ?
            </button>
            {showingHelp && (
                <Modal show={showingHelp} onHide={() => setShowHelp(false)}>
                    <Modal.Header closeButton>
                        <Modal.Title>Controls</Modal.Title>
                    </Modal.Header>
                    <Modal.Body>
                        <div className="help-panel">
                            <section>
                                <p>
                                    The camera can be moved with the mouse and
                                    with the WASD / arrow keys:
                                </p>

                                <div className="key-directions">
                                    <div className="key w-key">W ↑</div>
                                    <div className="key">A ←</div>
                                    <div className="key">S ↓</div>
                                    <div className="key">D →</div>
                                </div>
                            </section>

                            <section>
                                <p>Press Z and X to zoom in and out:</p>

                                <div className="key">Z +</div>
                                <div className="key">X -</div>
                            </section>

                            <section>
                                <p>
                                    There are shortcuts to reset the
                                    perspective:
                                </p>

                                <div className="number-keys">
                                    <div>
                                        <div className="key">1</div>
                                        Default view
                                    </div>
                                    <div>
                                        <div className="key">2</div>
                                        Top view
                                    </div>
                                    <div>
                                        <div className="key mb-0">3</div>
                                        Side view
                                    </div>
                                </div>
                            </section>
                        </div>
                    </Modal.Body>
                </Modal>
            )}
        </>
    );
};

export default Help;
