/* Copyright (c) 2015 - 2021, Nordic Semiconductor ASA
 *
 * All rights reserved.
 *
 * Use in source and binary forms, redistribution in binary form only, with
 * or without modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions in binary form, except as embedded into a Nordic
 *    Semiconductor ASA integrated circuit in a product or a software update for
 *    such product, must reproduce the above copyright notice, this list of
 *    conditions and the following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 2. Neither the name of Nordic Semiconductor ASA nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * 3. This software, with or without modification, must only be used with a Nordic
 *    Semiconductor ASA integrated circuit.
 *
 * 4. Any software provided in binary form under this license must not be reverse
 *    engineered, decompiled, modified and/or disassembled.
 *
 * THIS SOFTWARE IS PROVIDED BY NORDIC SEMICONDUCTOR ASA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL NORDIC SEMICONDUCTOR ASA OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import React from 'react';
import { useSelector } from 'react-redux';
import { Canvas } from 'react-three-fiber';
import { currentPane, Main } from 'pc-nrfconnect-shared';

import { deviceStore, ReadingState } from '../stores/deviceStore';
import { ReduxState } from '../stores/settingsStore';
import Help from './Perspective/Help';
import PerspectiveControls from './Perspective/PerspectiveControls';
import PositionViewer from './PositionViewer';

const Position: React.FC = () => {
    const showingPosition = useSelector<ReduxState>(currentPane) === 0; // Position Pane
    const readingState = deviceStore(state => state.readingState);

    if (!showingPosition) {
        return <></>;
    }
    return (
        <Main>
            <Canvas>
                <ambientLight />
                <PositionViewer />
            </Canvas>
            {readingState === ReadingState.CALIBRATION_WAITING && (
                <div className="calibration">
                    <div className="calibration-text">
                        Place the tag at the indicated position and click the
                        &apos;Tag placed&apos; button
                    </div>
                </div>
            )}
            <PerspectiveControls />
            <Help />
        </Main>
    );
};

export default Position;
