/* Copyright (c) 2015 - 2021, Nordic Semiconductor ASA
 *
 * All rights reserved.
 *
 * Use in source and binary forms, redistribution in binary form only, with
 * or without modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions in binary form, except as embedded into a Nordic
 *    Semiconductor ASA integrated circuit in a product or a software update for
 *    such product, must reproduce the above copyright notice, this list of
 *    conditions and the following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 2. Neither the name of Nordic Semiconductor ASA nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * 3. This software, with or without modification, must only be used with a Nordic
 *    Semiconductor ASA integrated circuit.
 *
 * 4. Any software provided in binary form under this license must not be reverse
 *    engineered, decompiled, modified and/or disassembled.
 *
 * THIS SOFTWARE IS PROVIDED BY NORDIC SEMICONDUCTOR ASA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL NORDIC SEMICONDUCTOR ASA OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import React from 'react';
import { Scatter } from 'react-chartjs-2';

import { generateColours, padding, sharedOptions } from './chart_styles';

const animation = { duration: 0 };

interface Props {
    name1: string;
    name2: string;
    uncal: number[];
    cal: number[];
}

const OffsetChart: React.FC<Props> = ({ name1, name2, uncal, cal }) => {
    const blue = generateColours('blue');
    const red = generateColours('red');

    const uncalData = uncal.map((e, index) => ({
        x: index,
        y: e,
    }));
    const calData = cal.map((e, index) => ({
        x: index,
        y: e,
    }));

    return (
        <Scatter
            type="scatter"
            data={{
                datasets: [
                    {
                        ...sharedOptions,
                        ...red,
                        label: 'uncalibrated',
                        data: uncalData,
                    },
                    {
                        ...sharedOptions,
                        ...blue,
                        label: 'calibrated',
                        data: calData,
                    },
                ],
            }}
            options={{
                maintainAspectRatio: false,
                animation,
                elements: {
                    line: {
                        tension: 0,
                    },
                },
                layout: {
                    padding,
                },
                legend: {
                    display: false,
                },
                plugins: {
                    title: {
                        display: true,
                        position: 'left',
                        text: `${name1}, ${name2}`,
                    },
                },
                tooltips: {
                    enabled: false,
                },
                scales: {
                    xAxes: [
                        {
                            scaleLabel: {
                                display: true,
                                labelString: 'Sample #',
                            },
                            ticks: {
                                stepSize: 1,
                                callback(value: string) {
                                    return parseInt(value, 10) % 5 === 0
                                        ? value
                                        : '';
                                },
                            },
                            gridLines: {
                                display: true,
                            },
                        },
                    ],
                    yAxes: [
                        {
                            ticks: {
                                min: 0,
                                max: 350,
                            },
                        },
                    ],
                },
            }}
        />
    );
};

export default OffsetChart;
