/* Copyright (c) 2015 - 2021, Nordic Semiconductor ASA
 *
 * All rights reserved.
 *
 * Use in source and binary forms, redistribution in binary form only, with
 * or without modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions in binary form, except as embedded into a Nordic
 *    Semiconductor ASA integrated circuit in a product or a software update for
 *    such product, must reproduce the above copyright notice, this list of
 *    conditions and the following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 2. Neither the name of Nordic Semiconductor ASA nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * 3. This software, with or without modification, must only be used with a Nordic
 *    Semiconductor ASA integrated circuit.
 *
 * 4. Any software provided in binary form under this license must not be reverse
 *    engineered, decompiled, modified and/or disassembled.
 *
 * THIS SOFTWARE IS PROVIDED BY NORDIC SEMICONDUCTOR ASA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL NORDIC SEMICONDUCTOR ASA OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import React from 'react';
import shallow from 'zustand/shallow';

import { deviceStore } from '../../stores/deviceStore';
import { Device } from '../../stores/deviceTypes';
import EditField from '../EditField';

interface Props {
    index: number;
    device: Device;
}

export const DeviceEditor: React.FC<Props> = ({ index, device }) => {
    const [roomSize, setDevicePosition, setDeviceRotation] = deviceStore(
        state => [
            state.roomSize,
            state.setDevicePosition,
            state.setDeviceRotation,
        ],
        shallow
    );

    return (
        <>
            <p className="editHeader">Position (m):</p>
            <div className="inline">
                <EditField
                    preText="x"
                    value={device.position.x}
                    range={{ min: 0, max: roomSize.x, decimals: 2 }}
                    onChange={val =>
                        setDevicePosition(
                            index,
                            device.position.clone().setX(val)
                        )
                    }
                />
                <EditField
                    preText="y"
                    value={device.position.y}
                    range={{ min: 0, max: roomSize.y, decimals: 2 }}
                    onChange={val =>
                        setDevicePosition(
                            index,
                            device.position.clone().setY(val)
                        )
                    }
                />
                <EditField
                    preText="z"
                    value={device.position.z}
                    range={{ min: 0, max: roomSize.z, decimals: 2 }}
                    onChange={val =>
                        setDevicePosition(
                            index,
                            device.position.clone().setZ(val)
                        )
                    }
                />
            </div>
            <p className="editHeader">Orientation (°):</p>
            <div className="inline">
                <EditField
                    preText="el"
                    value={-device.rotation.x}
                    range={{ min: -90, max: 90, decimals: 0 }}
                    onChange={val =>
                        setDeviceRotation(
                            index,
                            device.rotation.clone().setX(-val)
                        )
                    }
                />
                <EditField
                    preText="az"
                    value={device.rotation.y}
                    range={{ min: 0, max: 359, decimals: 0 }}
                    onChange={val =>
                        setDeviceRotation(
                            index,
                            device.rotation.clone().setY(val)
                        )
                    }
                />
                <EditField
                    preText="rot"
                    value={device.rotation.z}
                    range={{ min: 0, max: 359, decimals: 0 }}
                    onChange={val =>
                        setDeviceRotation(
                            index,
                            device.rotation.clone().setZ(val)
                        )
                    }
                />
            </div>
        </>
    );
};

export default DeviceEditor;
