/* Copyright (c) 2015 - 2021, Nordic Semiconductor ASA
 *
 * All rights reserved.
 *
 * Use in source and binary forms, redistribution in binary form only, with
 * or without modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions in binary form, except as embedded into a Nordic
 *    Semiconductor ASA integrated circuit in a product or a software update for
 *    such product, must reproduce the above copyright notice, this list of
 *    conditions and the following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 2. Neither the name of Nordic Semiconductor ASA nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * 3. This software, with or without modification, must only be used with a Nordic
 *    Semiconductor ASA integrated circuit.
 *
 * 4. Any software provided in binary form under this license must not be reverse
 *    engineered, decompiled, modified and/or disassembled.
 *
 * THIS SOFTWARE IS PROVIDED BY NORDIC SEMICONDUCTOR ASA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL NORDIC SEMICONDUCTOR ASA OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import React from 'react';
import Button from 'react-bootstrap/Button';
import { SidePanel } from 'pc-nrfconnect-shared';
import shallow from 'zustand/shallow';

import { deviceStore, ReadingState } from '../stores/deviceStore';
import DeviceList from './Device/DeviceList';
import RoomEdit from './RoomEdit';
import Settings from './Settings';

// Used as dummy device identifier.
let dummyDeviceCount = 0;

const DirectionSidePanel: React.FC = () => {
    const [readingState, setReadingState, addDevice] = deviceStore(
        state => [state.readingState, state.setReadingState, state.addDevice],
        shallow
    );

    function onCalibrate() {
        switch (readingState) {
            case ReadingState.OFF:
                setReadingState(ReadingState.CALIBRATION_INITIALIZE);
                break;
            case ReadingState.CALIBRATION_WAITING:
                setReadingState(ReadingState.CALIBRATION_RECORD);
                break;
            default:
        }
    }

    function onReading() {
        switch (readingState) {
            case ReadingState.OFF:
                setReadingState(ReadingState.READING);
                break;
            case ReadingState.READING:
                setReadingState(ReadingState.OFF);
                break;
            default:
        }
    }

    return (
        <SidePanel>
            <div className="sidepanel-buttons">
                <Button
                    variant="secondary"
                    onClick={() => {
                        dummyDeviceCount += 1;
                        addDevice(
                            {
                                boardVersion: '',
                                serialNumber: `${dummyDeviceCount}`,
                                traits: [],
                                nickname: `Dummy ${dummyDeviceCount}`,
                            },
                            undefined
                        );
                    }}
                    disabled={readingState !== ReadingState.OFF}
                >
                    Add dummy device
                </Button>
                <Button
                    variant="secondary"
                    onClick={onReading}
                    disabled={
                        readingState >= ReadingState.CALIBRATION_INITIALIZE
                    }
                >
                    {(readingState === ReadingState.READING &&
                        'Stop reading') ||
                        'Start reading'}
                </Button>
                <Button
                    variant="secondary"
                    onClick={onCalibrate}
                    disabled={
                        readingState !== ReadingState.OFF &&
                        readingState !== ReadingState.CALIBRATION_WAITING
                    }
                >
                    {(readingState >= ReadingState.CALIBRATION_INITIALIZE &&
                        'Tag placed') ||
                        'Start calibrating'}
                </Button>
            </div>
            <Settings />
            <RoomEdit />
            <DeviceList />
        </SidePanel>
    );
};

export default DirectionSidePanel;
