/* Copyright (c) 2015 - 2021, Nordic Semiconductor ASA
 *
 * All rights reserved.
 *
 * Use in source and binary forms, redistribution in binary form only, with
 * or without modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions in binary form, except as embedded into a Nordic
 *    Semiconductor ASA integrated circuit in a product or a software update for
 *    such product, must reproduce the above copyright notice, this list of
 *    conditions and the following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 2. Neither the name of Nordic Semiconductor ASA nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * 3. This software, with or without modification, must only be used with a Nordic
 *    Semiconductor ASA integrated circuit.
 *
 * 4. Any software provided in binary form under this license must not be reverse
 *    engineered, decompiled, modified and/or disassembled.
 *
 * THIS SOFTWARE IS PROVIDED BY NORDIC SEMICONDUCTOR ASA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL NORDIC SEMICONDUCTOR ASA OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import Store from 'electron-store';
import { NrfConnectState } from 'pc-nrfconnect-shared';
import { Vector3 } from 'three';

import { Device } from './deviceTypes';

type ReduxState = NrfConnectState<Record<string, unknown>>;

export const detectedDevices = (state: ReduxState) => state.device.devices;

const store = new Store({ name: 'pc-nrfconnect-positioningsystem' });

const getPersistedDevices = () => store.get(`devices`, []) as Device[];

export const persistDevices = (devices: Device[]) => {
    const savedDevices = getPersistedDevices();

    devices.forEach(d => {
        const index = savedDevices.findIndex(
            savedDevice => savedDevice.serialNumber === d.serialNumber
        );
        if (index < 0) {
            savedDevices.push(d);
        } else {
            savedDevices[index] = d;
        }
    });
    store.set('devices', savedDevices);
};

export const getPersistedDevice = (serialNumber: string) => {
    const savedDevices = getPersistedDevices();
    if (savedDevices.length > 0) {
        return savedDevices.find(d => d.serialNumber === serialNumber);
    }
};

export const persistRoom = (room: Vector3) => store.set('room', room);

export const getPersistedRoom = () =>
    store.get(`room`, new Vector3(5, 5, 5)) as Vector3;

export const persistAxesSetting = (showAxes: boolean) =>
    store.set('showAxes', showAxes);

export const persistLabelSetting = (showLabels: boolean) =>
    store.set('showLabels', showLabels);

export const persistCoverageSetting = (showCoverage: boolean) =>
    store.set('showCoverage', showCoverage);

export const persistCoverageAngle = (coverageAngle: number) =>
    store.set('coverageAngle', coverageAngle);

export const persistDirectionVectorSetting = (showDirectionVectors: boolean) =>
    store.set('showDirectionVectors', showDirectionVectors);

export const getPersistedAxesSetting = () =>
    store.get('showAxes', false) as boolean;

export const getPersistedLabelSetting = () =>
    store.get('showLabels', false) as boolean;

export const getPersistedCoverageSetting = () =>
    store.get('showCoverage', false) as boolean;

export const getPersistedCoverageAngle = () =>
    store.get('coverageAngle', 70) as number;

export const getPersistedDirectionVectorSetting = () =>
    store.get('showDirectionVectors', false) as boolean;
